# PukiWiki Dumper


![Dynamic JSON Badge](https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Farchive.org%2Fadvancedsearch.php%3Fq%3Dsubject%3APukiWikiDumper%26rows%3D1%26page%3D1%26output%3Djson&query=%24.response.numFound&label=PukiWiki%20Dumps%40IA)
[![PyPI version](https://badge.fury.io/py/pukiwikidumper.svg)](https://badge.fury.io/py/pukiwikidumper)

> A tool for archiving PukiWiki.

## About

There is no detailed documentation yet.  
PukiWiki Dumper is very similar to [saveweb/DokuWiki-Dumper](https://github.com/saveweb/DokuWiki-Dumper), you can refer to the documentation of DokuWiki Dumper.

## See also

<https://wiki.saveweb.org/pukiwiki>  
saveweb/wikiteam3  
saveweb/dokuwiki-dumper  
digitaldwagon/wikibot  
<https://wiki.archiveteam.org/index.php/PukiWiki>
